# pyright: reportImportCycles=false
from __future__ import annotations

from typing import TYPE_CHECKING
from pathlib import Path

from .metadatas.bench import Bench as mBench
from .bench import Bench
from .benches import Sdb1, Sdb2, Sneb, Sweb, Sqb1

if TYPE_CHECKING:
    from .acquisition import Acquisition


def BenchFactory(
    name: str,
    metadata: mBench,
    acquisition: Acquisition,
    model_file: Path,
) -> Sdb1 | Sdb2 | Sqb1 | Sneb | Sweb:
    """
    Factory to safely create bench instance
    """
    bench = Bench()  # "blank" bench
    if name == "SDB1":
        bench = Sdb1()
    elif name == "SDB2":
        bench = Sdb2()
    elif name == "SNEB":
        bench = Sneb()
    elif name == "SWEB":
        bench = Sweb()
    elif name == "SQB1":
        bench = Sqb1()
    else:
        raise Exception(_("unknown bench {}").format(name))
    bench.acquisition = acquisition
    bench.metadata = metadata
    bench.set_coupling(model_file)  # pyright: ignore[reportUnusedCallResult]
    bench.load()  # pyright: ignore[reportUnusedCallResult]

    return bench
