from __future__ import annotations

from pathlib import Path
from typing import TYPE_CHECKING

from science_signal import Signal  # pyright: ignore[reportMissingTypeStubs]
from scipy.io.matlab import loadmat  # pyright: ignore[reportMissingTypeStubs]

if TYPE_CHECKING:
    from .bench import Bench


class Coupling:
    """
    Coupling function

    Parameters
    ----------
    data: list[Signal]
        Data of the two transfer functions
    file: Path
        Path of the modelisation file
    bench: Bench
        Bench associated to this coupling value
    """

    def __init__(self, file: Path, bench: Bench) -> None:
        """
        Initializer of Coupling class

        Parameters
        ----------
        file: Path
            Path of the modelisation file
        """
        if not file.is_file():
            raise Exception(
                _("modelisation file {} does not exist").format(
                    str(file)
                )
            )
        self.file: Path = file
        self.bench: Bench = bench

        modelisation_data = loadmat(self.file)
        modelisation_name = self.bench.name
        if modelisation_name in ["SDB2", "SQB1"]:
            modelisation_name = "SDB1"

        self.data: list[Signal] = [
            Signal(modelisation_data["freq"][0], abs(coupling))
            for coupling in modelisation_data[
                modelisation_name + "coupling"
            ]
        ]
